@@ -106,7 +106,7 @@ class hexagon_grid:
     def __init__(self,
                  data, 
                  spacing,
-                 hexagon_dis = True,
+                 hexagon_dis:bool,
                  area_threshold:float = None
                  ):
         self.data = data
@@ -184,7 +184,7 @@ class hexagon_grid:
                                 gpd.overlay(gdf.explode().reset_index().drop(['level_0', 'level_1'], axis = 1),
                                             datax, how='intersection'),
                                 how = 'union')[['geometry']].copy()
-        if hexagon_dis:
+        if hexagon_dis == True:
             self.geosolution = final_hexa
         else:
             if self.area_threshold == None:
